16.69. cdist-type__install_fstab(7) — cdist 6.9.4 documentation

# 16.69. cdist-type__install_fstab(7)

## 16.69.1. NAME

cdist-type__install_fstab - generate /etc/fstab during installation

## 16.69.2. DESCRIPTION

Uses __install_generate_fstab to generate a /etc/fstab file and uploads it to the target machine at ${prefix}/etc/fstab.

## 16.69.3. REQUIRED PARAMETERS

None

## 16.69.4. OPTIONAL PARAMETERS

prefix

  The prefix under which to generate the /etc/fstab file. Defaults to /target.

## 16.69.5. EXAMPLES

    __install_fstab

    __install_fstab --prefix /mnt/target

## 16.69.6. SEE ALSO

cdist-type__install_generate_fstab(7), cdist-type__install_mount(7)

## 16.69.7. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 16.69.8. COPYING

Copyright (C) 2011 Steven Armstrong. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.